@@ -1,3 +1,4 @@
+use core::fmt::Debug;
 use downcast_rs::{Downcast, impl_downcast};
 
 use ross_protocol::packet::Packet;
@@ -17,6 +18,7 @@ pub const NONE_PRODUCER_CODE: u16 = 0x0000;
 pub const BCM_CHANGE_BRIGHTNESS_PRODUCER_CODE: u16 = 0x0001;
 pub const BCM_CHANGE_BRIGHTNESS_STATE_PRODUCER_CODE: u16 = 0x0002;
 
+#[cfg_attr(feature = "std", typetag::serde(tag = "type"))]
 pub trait Producer: Downcast {
     fn produce(
         &self,
@@ -27,3 +29,9 @@ pub trait Producer: Downcast {
 }
 
 impl_downcast!(Producer);
+
+impl Debug for dyn Producer {
+    fn fmt(&self, f: &mut core::fmt::Formatter<'_>) -> core::fmt::Result {
+        write!(f, "Producer")
+    }
+}
